@@ -43,8 +43,14 @@ class TranslationFileMapping(proto.Message):
             corresponding input file to.
     """
 
-    input_path = proto.Field(proto.STRING, number=1,)
-    output_path = proto.Field(proto.STRING, number=2,)
+    input_path = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    output_path = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class TranslationTaskDetails(proto.Message):
@@ -130,26 +136,59 @@ class TranslationTaskDetails(proto.Message):
         TIMESTAMP = 7
 
     teradata_options = proto.Field(
-        proto.MESSAGE, number=10, oneof="language_options", message="TeradataOptions",
+        proto.MESSAGE,
+        number=10,
+        oneof="language_options",
+        message="TeradataOptions",
     )
     bteq_options = proto.Field(
-        proto.MESSAGE, number=11, oneof="language_options", message="BteqOptions",
+        proto.MESSAGE,
+        number=11,
+        oneof="language_options",
+        message="BteqOptions",
+    )
+    input_path = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    output_path = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    input_path = proto.Field(proto.STRING, number=1,)
-    output_path = proto.Field(proto.STRING, number=2,)
     file_paths = proto.RepeatedField(
-        proto.MESSAGE, number=12, message="TranslationFileMapping",
+        proto.MESSAGE,
+        number=12,
+        message="TranslationFileMapping",
+    )
+    schema_path = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    file_encoding = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum=FileEncoding,
     )
-    schema_path = proto.Field(proto.STRING, number=3,)
-    file_encoding = proto.Field(proto.ENUM, number=4, enum=FileEncoding,)
     identifier_settings = proto.Field(
-        proto.MESSAGE, number=5, message="IdentifierSettings",
+        proto.MESSAGE,
+        number=5,
+        message="IdentifierSettings",
     )
     special_token_map = proto.MapField(
-        proto.STRING, proto.ENUM, number=6, enum=TokenType,
+        proto.STRING,
+        proto.ENUM,
+        number=6,
+        enum=TokenType,
+    )
+    filter = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message="Filter",
+    )
+    translation_exception_table = proto.Field(
+        proto.STRING,
+        number=13,
     )
-    filter = proto.Field(proto.MESSAGE, number=7, message="Filter",)
-    translation_exception_table = proto.Field(proto.STRING, number=13,)
 
 
 class Filter(proto.Message):
@@ -161,7 +200,10 @@ class Filter(proto.Message):
             processing for input files.
     """
 
-    input_file_exclusion_prefixes = proto.RepeatedField(proto.STRING, number=1,)
+    input_file_exclusion_prefixes = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
 
 
 class IdentifierSettings(proto.Message):
@@ -189,15 +231,20 @@ class IdentifierSettings(proto.Message):
         NONE = 1
         REWRITE_ALL = 2
 
-    output_identifier_case = proto.Field(proto.ENUM, number=1, enum=IdentifierCase,)
+    output_identifier_case = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=IdentifierCase,
+    )
     identifier_rewrite_mode = proto.Field(
-        proto.ENUM, number=2, enum=IdentifierRewriteMode,
+        proto.ENUM,
+        number=2,
+        enum=IdentifierRewriteMode,
     )
 
 
 class TeradataOptions(proto.Message):
-    r"""Teradata SQL specific translation task related settings.
-    """
+    r"""Teradata SQL specific translation task related settings."""
 
 
 class BteqOptions(proto.Message):
@@ -219,9 +266,20 @@ class BteqOptions(proto.Message):
             translation (the value).
     """
 
-    project_dataset = proto.Field(proto.MESSAGE, number=1, message="DatasetReference",)
-    default_path_uri = proto.Field(proto.STRING, number=2,)
-    file_replacement_map = proto.MapField(proto.STRING, proto.STRING, number=3,)
+    project_dataset = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="DatasetReference",
+    )
+    default_path_uri = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    file_replacement_map = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=3,
+    )
 
 
 class DatasetReference(proto.Message):
@@ -237,8 +295,14 @@ class DatasetReference(proto.Message):
             dataset.
     """
 
-    dataset_id = proto.Field(proto.STRING, number=1,)
-    project_id = proto.Field(proto.STRING, number=2,)
+    dataset_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    project_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
